Stan Math Library: stan/math/fwd/mat/fun/trace_gen_quad_form.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

trace_gen_quad_form.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_MAT_FUN_TRACE_GEN_QUAD_FORM_HPP
2 #define STAN_MATH_FWD_MAT_FUN_TRACE_GEN_QUAD_FORM_HPP
3
4 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
5 #include <stan/math/prim/mat/err/check_square.hpp>
6 #include <stan/math/fwd/mat/fun/multiply.hpp>
7 #include <stan/math/prim/mat/fun/trace.hpp>
8 #include <stan/math/prim/mat/fun/multiply.hpp>
9 #include <stan/math/prim/mat/fun/transpose.hpp>
10
11 namespace stan {
12 namespace math {
13 template<int RD, int CD, int RA, int CA, int RB, int CB, typename T>
14 inline fvar<T>
15 trace_gen_quad_form(const Eigen::Matrix<fvar<T>, RD, CD> &D,
16 const Eigen::Matrix<fvar<T>, RA, CA> &A,
17 const Eigen::Matrix<fvar<T>, RB, CB> &B) {
18 using stan::math::multiply;
19 using stan::math::multiply;
20
21 stan::math::check_square("trace_gen_quad_form", "A", A);
22 stan::math::check_square("trace_gen_quad_form", "D", D);
23 stan::math::check_multiplicable("trace_gen_quad_form",
24 "A", A,
25 "B", B);
26 stan::math::check_multiplicable("trace_gen_quad_form",
27 "B", B,
28 "D", D);
29 return stan::math::trace(multiply(multiply(D, stan::math::transpose(B)),
30 multiply(A, B)));
31 }
32 }
33 }
34
35 #endif
36
multiply.hpp
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::multiply
Eigen::Matrix< fvar< T >, R1, C1 > multiply(const Eigen::Matrix< fvar< T >, R1, C1 > &m, const fvar< T > &c)
Definition: multiply.hpp:21
multiply.hpp
transpose.hpp
stan::math::trace_gen_quad_form
fvar< T > trace_gen_quad_form(const Eigen::Matrix< fvar< T >, RD, CD > &D, const Eigen::Matrix< fvar< T >, RA, CA > &A, const Eigen::Matrix< fvar< T >, RB, CB > &B)
Definition: trace_gen_quad_form.hpp:15
trace.hpp
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
stan::math::trace
T trace(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
Returns the trace of the specified matrix.
Definition: trace.hpp:20
stan::math::transpose
Eigen::Matrix< T, C, R > transpose(const Eigen::Matrix< T, R, C > &m)
Definition: transpose.hpp:12
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
stan::math::fvar
Definition: fvar.hpp:13
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.